@@ -34,6 +34,9 @@
 #' product installations.
 #' @param installed_end_date Date object for the ending date of
 #' product installations.
+#' @param chatty The function can be chatty, sending a message to the console
+#' for every iteration through a product Id. Many API calls may be required
+#' and the console may get very long and it may slow down the execution.
 #'
 #' @import dplyr
 #' @importFrom magrittr "%>%"
@@ -71,7 +74,8 @@
 #'
 get_client_metadata <- function(rev_product_ids, rev_session_id, rev_username,
                                 product_properties_df, desired_properties,
-                                installed_start_date, installed_end_date) {
+                                installed_start_date, installed_end_date,
+                                chatty = FALSE) {
   product_df_base <- tibble(
     revenera_product_id = character(),
     client_id = character(), property_friendly_name =
@@ -79,7 +83,9 @@ get_client_metadata <- function(rev_product_ids, rev_session_id, rev_username,
   )
 
   get_one_product_metadata <- function(product_iter) {
-    message(paste0("Starting product id ", product_iter))
+    if (chatty) {
+      message(paste0("Starting product id ", product_iter))
+    }
 
     custom_property_names <- product_properties_df %>%
       filter(
@@ -102,7 +108,9 @@ get_client_metadata <- function(rev_product_ids, rev_session_id, rev_username,
     keep_going <- TRUE
 
     while (keep_going == TRUE) {
-      message(paste0("iteration ", i))
+      if (chatty) {
+        message(paste0("iteration ", i))
+      }
 
       i <- i + 1
 
@@ -153,8 +161,9 @@ get_client_metadata <- function(rev_product_ids, rev_session_id, rev_username,
 
       request_content <- httr::content(request, "text", encoding = "ISO-8859-1")
       content_json <- jsonlite::fromJSON(request_content, flatten = TRUE)
-
-      message(paste0("nextClientId = ", content_json$nextClientId))
+      if (chatty) {
+        message(paste0("nextClientId = ", content_json$nextClientId))
+      }
 
       build_data_frame <- function(c) {
         properties <- as.data.frame(content_json$results[c])
